@@ -16,18 +16,11 @@
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- *
- * @file globus_gass_transfer_send_recv.c Send/Receive Data
+ * @file globus_gass_transfer_send_recv.c
+ * @brief Send/Receive Data
  *
  * This module implements the send and receive functionality of the
  * GASS transfer library.
- *  
- * CVS Information: 
- *
- * $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_gass_transfer_send_recv.c,v $
- * $Date: 2011/02/03 21:46:40 $
- * $Revision: 1.11 $
- * $Author: bester $
  */
 #endif
 
@@ -470,7 +463,7 @@ globus_i_gass_transfer_fail(
 	    GLOBUS_NULL,
 	    &delay_time,
 	    globus_l_gass_transfer_drain_callbacks,
-	    (void *) request);
+	    (void *) (intptr_t) request);
 	break;
       case GLOBUS_GASS_TRANSFER_REQUEST_FAILED:
       case GLOBUS_GASS_TRANSFER_REQUEST_SERVER_FAIL1:
@@ -727,7 +720,7 @@ globus_l_gass_transfer_drain_callbacks(
     globus_gass_transfer_callback_t		callback;
     void *					callback_arg;
 
-    request = (globus_gass_transfer_request_t) arg;
+    request = (globus_gass_transfer_request_t) (intptr_t) arg;
 
     req =
 	globus_handle_table_lookup(&globus_i_gass_transfer_request_handles,
